@@ -548,7 +548,7 @@ class JSONAPI(object):
             return ToManyExpectedError(model, resource, relationship)
 
         response = JSONAPIResponse()
-        response.data = {'data': []}
+        response.data = []
 
         session.add(resource)
 
@@ -648,7 +648,7 @@ class JSONAPI(object):
         start, end = self._parse_page(query)
 
         response = JSONAPIResponse()
-        response.data = {'data': []}
+        response.data['data'] = []
 
         for instance in collection:
             try:
